@@ -19,7 +19,7 @@ decision surface of each classifier.
 First compose some sample data -- no PyMVPA involved.
 """
 
-import numpy as N
+import numpy as np
 
 # set up the labeled data
 # two skewed 2-D distributions
@@ -27,12 +27,12 @@ num_dat = 200
 dist = 4
 # Absolute max value allowed. Just to assure proper plots
 xyamax = 10
-feat_pos=N.random.randn(2, num_dat)
+feat_pos=np.random.randn(2, num_dat)
 feat_pos[0, :] *= 2.
 feat_pos[1, :] *= .5
 feat_pos[0, :] += dist
 feat_pos = feat_pos.clip(-xyamax, xyamax)
-feat_neg=N.random.randn(2, num_dat)
+feat_neg=np.random.randn(2, num_dat)
 feat_neg[0, :] *= .5
 feat_neg[1, :] *= 2.
 feat_neg[0, :] -= dist
@@ -40,28 +40,29 @@ feat_neg = feat_neg.clip(-xyamax, xyamax)
 
 # set up the testing features
 npoints = 101
-x1 = N.linspace(-xyamax, xyamax, npoints)
-x2 = N.linspace(-xyamax, xyamax, npoints)
-x,y = N.meshgrid(x1, x2);
-feat_test = N.array((N.ravel(x), N.ravel(y)))
+x1 = np.linspace(-xyamax, xyamax, npoints)
+x2 = np.linspace(-xyamax, xyamax, npoints)
+x,y = np.meshgrid(x1, x2);
+feat_test = np.array((np.ravel(x), np.ravel(y)))
 
 """Now load PyMVPA and convert the data into a proper
-:class:`~mvpa.datasets.base.Dataset`."""
+:class:`~mvpa2.datasets.base.Dataset`."""
 
-from mvpa.suite import *
+from mvpa2.suite import *
 
 # create the pymvpa dataset from the labeled features
-patternsPos = Dataset(samples=feat_pos.T, labels=1)
-patternsNeg = Dataset(samples=feat_neg.T, labels=0)
-ds_lin = patternsPos + patternsNeg
+patternsPos = dataset_wizard(samples=feat_pos.T, targets=1)
+patternsNeg = dataset_wizard(samples=feat_neg.T, targets=0)
+ds_lin = vstack((patternsPos, patternsNeg))
 
 """Let's add another dataset: XOR. This problem is not linear separable
 and therefore need a non-linear classifier to be solved. The dataset is
 provided by the PyMVPA dataset warehouse.
 """
 
-# 30 samples per condition, SNR 3
-ds_nl = pureMultivariateSignal(30,3)
+# 30 samples per condition, SNR 2
+ds_nl = pure_multivariate_signal(30, 2)
+l1 = ds_nl.sa['targets'].unique[1]
 
 datasets = {'linear': ds_lin, 'non-linear': ds_nl}
 
@@ -70,18 +71,25 @@ classifier involves almost no runtime costs, so it is easily possible
 compile a long list, if necessary."""
 
 # set up classifiers to try out
-clfs = {'Ridge Regression': RidgeReg(),
+clfs = {
+        'Ridge Regression': RidgeReg(),
         'Linear SVM': LinearNuSVMC(probability=1,
-                      enable_states=['probabilities']),
+                      enable_ca=['probabilities']),
         'RBF SVM': RbfNuSVMC(probability=1,
-                      enable_states=['probabilities']),
+                      enable_ca=['probabilities']),
         'SMLR': SMLR(lm=0.01),
         'Logistic Regression': PLR(criterion=0.00001),
-        'k-Nearest-Neighbour': kNN(k=10),
+        '3-Nearest-Neighbour': kNN(k=3),
+        '10-Nearest-Neighbour': kNN(k=10),
         'GNB': GNB(common_variance=True),
         'GNB(common_variance=False)': GNB(common_variance=False),
+        'LDA': LDA(),
+        'QDA': QDA(),
         }
 
+# How many rows/columns we need
+nx = int(ceil(np.sqrt(len(clfs))))
+ny = int(ceil(len(clfs)/float(nx)))
 
 """Now we are ready to run the classifiers. The following loop trains
 and queries each classifier to finally generate a nice plot showing
@@ -93,31 +101,23 @@ for id, ds in datasets.iteritems():
     fig = 0
 
     # make a new figure
-    P.figure(figsize=(9, 9))
+    pl.figure(figsize=(nx*4, ny*4))
 
     print "Processing %s problem..." % id
 
-    for c in clfs:
+    for c in sorted(clfs):
         # tell which one we are doing
         print "Running %s classifier..." % (c)
 
         # make a new subplot for each classifier
         fig += 1
-        P.subplot(3, 3, fig)
-
-        # plot the training points
-        P.plot(ds.samples[ds.labels == 1, 0],
-               ds.samples[ds.labels == 1, 1],
-               "r.")
-        P.plot(ds.samples[ds.labels == 0, 0],
-               ds.samples[ds.labels == 0, 1],
-               "b.")
+        pl.subplot(ny, nx, fig)
 
         # select the clasifier
         clf = clfs[c]
 
-        # enable saving of the values used for the prediction
-        clf.states.enable('values')
+        # enable saving of the estimates used for the prediction
+        clf.ca.enable('estimates')
 
         # train with the known points
         clf.train(ds)
@@ -126,37 +126,57 @@ for id, ds in datasets.iteritems():
         pre = clf.predict(feat_test.T)
 
         # if ridge, use the prediction, otherwise use the values
-        if c == 'Ridge Regression' or c.startswith('k-Nearest'):
+        if c == 'Ridge Regression':
             # use the prediction
-            res = N.asarray(pre)
+            res = np.asarray(pre)
+        elif 'Nearest-Ne' in c:
+            # Use the dictionaries with votes
+            res = np.array([e[l1] for e in clf.ca.estimates]) \
+                  / np.sum([e.values() for e in clf.ca.estimates], axis=1)
         elif c == 'Logistic Regression':
             # get out the values used for the prediction
-            res = N.asarray(clf.values)
+            res = np.asarray(clf.ca.estimates)
         elif c in ['SMLR']:
-            res = N.asarray(clf.values[:, 1])
-        elif c.startswith('GNB'):
-            # Since probabilities are raw: for visualization lets
-            # operate on logprobs and in comparison one to another
-            res = clf.values[:, 1] - clf.values[:, 0]
+            res = np.asarray(clf.ca.estimates[:, 1])
+        elif c in ['LDA', 'QDA'] or c.startswith('GNB'):
+            # Since probabilities are logprobs -- just for
+            # visualization of trade-off just plot relative
+            # "trade-off" which determines decision boundaries if an
+            # alternative log-odd value was chosen for a cutoff
+            res = np.asarray(clf.ca.estimates[:, 1]
+                             - clf.ca.estimates[:, 0])
             # Scale and position around 0.5
-            res = 0.5 + res/max(N.abs(res))
+            res = 0.5 + res/max(np.abs(res))
         else:
             # get the probabilities from the svm
-            res = N.asarray([(q[1][1] - q[1][0] + 1) / 2
-                    for q in clf.probabilities])
+            res = np.asarray([(q[1][1] - q[1][0] + 1) / 2
+                    for q in clf.ca.probabilities])
 
         # reshape the results
-        z = N.asarray(res).reshape((npoints, npoints))
+        z = np.asarray(res).reshape((npoints, npoints))
 
         # plot the predictions
-        P.pcolor(x, y, z, shading='interp')
-        P.clim(0, 1)
-        P.colorbar()
-        P.contour(x, y, z, linewidths=1, colors='black', hold=True)
-        P.axis('tight')
+        pl.pcolor(x, y, z, shading='interp')
+        pl.clim(0, 1)
+        pl.colorbar()
+        # plot decision surfaces at few levels to emphasize the
+        # topology
+        pl.contour(x, y, z, [0.1, 0.4, 0.5, 0.6, 0.9],
+                   linestyles=['dotted', 'dashed', 'solid', 'dashed', 'dotted'],
+                   linewidths=1, colors='black', hold=True)
+
+        # plot the training points
+        pl.plot(ds.samples[ds.targets == 1, 0],
+               ds.samples[ds.targets == 1, 1],
+               "r.")
+        pl.plot(ds.samples[ds.targets == 0, 0],
+               ds.samples[ds.targets == 0, 1],
+               "b.")
+
+        pl.axis('tight')
         # add the title
-        P.title(c)
+        pl.title(c)
 
 if cfg.getboolean('examples', 'interactive', True):
     # show all the cool figures
-    P.show()
+    pl.show()
