@@ -157,6 +157,7 @@ from mvpa2.base.collections import Collection  # ArrayCollectable
 from mvpa2.misc.neighborhood import QueryEngineInterface
 from mvpa2.measures.searchlight import Searchlight
 from mvpa2.base import debug, warning
+from mvpa2.mappers.flatten import FlattenMapper
 
 
 
@@ -187,7 +188,6 @@ def _from_singleton(x, ndim=2):
                          (s, x, x.shape,))
     return x[(0,) * ndim]
 
-
 # dictionary indicating whether elements in .fa, .sa and .a must be
 # transposed for CoSMoMVPA data representation. As in CoSMoMVPA a dataset
 # with .samples PxQ the elements in .fa must be ?xQ, (only) .fa requires
@@ -349,18 +349,20 @@ def _attributes_dict2cosmo(ds):
                 dtypes.append((k, 'O'))
                 values.append(value)
 
-            dtype = np.dtype(dtypes)
-            arr = np.array([[tuple(values)]], dtype=dtype)
+            if len(dtypes) > 0:
+                dtype = np.dtype(dtypes)
+                arr = np.array([[tuple(values)]], dtype=dtype)
 
-            cosmo[fieldname] = arr
+                cosmo[fieldname] = arr
 
     return cosmo
 
 
 
-def _mat_replace_matlab_function_by_string(x):
+def _mat_replace_functions_by_string(x):
     '''
-    Replace matlab function handles (as read by matread) by a string.
+    Replace matlab function handles (as read by matread) and FlattenMapper
+    objects by a string.
 
     Parameters
     ----------
@@ -369,24 +371,28 @@ def _mat_replace_matlab_function_by_string(x):
     Returns
     -------
     y : object
-        if x is a scipy.io.matlab.mio5_params.MatlabFunction then
+        if x is a scipy.io.matlab.mio5_params.MatlabFunction or
+        an mvpa2.mappers.flatten.FlattenMapper instance, then
         y is a string representation of x, otherwise y is equal to x
 
     Notes
     -----
-    scipy can read but not write Matlab function hanndles; the use case of
+    scipy can read but not write Matlab function handles; the use case of
     this function is to replace such function handles by something that scipy
     can write
     '''
 
-    if isinstance(x, matlab.mio5_params.MatlabFunction):
+    unsupported_classes = (matlab.mio5_params.MatlabFunction,
+                           FlattenMapper)
+
+    if isinstance(x, unsupported_classes):
         return np.asarray('%s' % x)
 
     return None
 
 
 
-def _mat_make_saveable(x, fixer=_mat_replace_matlab_function_by_string):
+def _mat_make_saveable(x, fixer=_mat_replace_functions_by_string):
     '''
     Make a Matlab data structure saveable by scipy's matsave
 
@@ -484,16 +490,20 @@ def _check_cosmo_dataset(cosmo):
 
     # ignore NaNs and infinity
     nonzero_msk = np.logical_and(np.isfinite(samples), samples != 0)
-    max_nonzero = np.max(np.abs(samples[nonzero_msk]))
 
-    # see how many decimals in the largest absolute value
-    decimals_nonzero = np.log10(max_nonzero)
+    if np.any(nonzero_msk):
+        max_nonzero = np.max(np.abs(samples[nonzero_msk]))
 
-    if abs(decimals_nonzero) > warn_for_extreme_values_decimals:
-        msg = ('Samples have extreme values, maximum absolute value is %s; '
-               'This may affect some analyses. Considering scaling the samples, '
-               'e.g. by a factor of 10**%d ' % (max_nonzero, -decimals_nonzero))
-        warning(msg)
+        # see how many decimals in the largest absolute value
+        decimals_nonzero = np.log10(max_nonzero)
+
+        if abs(decimals_nonzero) > warn_for_extreme_values_decimals:
+            msg = (
+                'Samples have extreme values, maximum absolute value is %s; '
+                'This may affect some analyses. Considering scaling the samples, '
+                'e.g. by a factor of 10**%d ' % (
+                    max_nonzero, -decimals_nonzero))
+            warning(msg)
 
 
 
@@ -663,7 +673,6 @@ class CosmoQueryEngine(QueryEngineInterface):
 
     '''
 
-
     def __init__(self, mapping, a=None, fa=None):
         '''
         Parameters
@@ -709,7 +718,6 @@ class CosmoQueryEngine(QueryEngineInterface):
         attributes['samples'] = np.zeros((0, nfeatures), dtype=np.int_)
         self._dataset_template = Dataset(**attributes)[:, ids]
 
-
     @staticmethod
     def _check_mapping(mapping):
         '''
@@ -722,14 +730,14 @@ class CosmoQueryEngine(QueryEngineInterface):
             if not np.isscalar(k):
                 raise ValueError('Key %s not a scalar' % k)
             if not isinstance(k, int):
-                raise ValueError('Keys %s must be int, found %s' % (k, type(k)))
+                raise ValueError(
+                    'Keys %s must be int, found %s' % (k, type(k)))
             if not isinstance(v, np.ndarray):
                 raise TypeError('Value %s for key %s must be numpy array' %
                                 (v, k))
             if not np.issubdtype(np.int_, v.dtype):
                 raise ValueError('Value %s for key %s must be int' % (v, k))
 
-
     @classmethod
     def from_mat(cls, neighbors, a=None, fa=None, origin=None):
         '''
@@ -778,7 +786,6 @@ class CosmoQueryEngine(QueryEngineInterface):
 
         return cls(mapping, a=a, fa=fa)
 
-
     def __repr__(self):
         '''
         Return representation of this instance
@@ -790,7 +797,6 @@ class CosmoQueryEngine(QueryEngineInterface):
                                                 template.a,
                                                 template.fa)
 
-
     def __str__(self):
         '''
         Return string summary of this instance
@@ -805,7 +811,6 @@ class CosmoQueryEngine(QueryEngineInterface):
                  ', '.join(template.fa.keys()),
                  ', '.join(template.a.keys())))
 
-
     def __reduce__(self):
         '''
         Return state of the instance that can be pickled
@@ -813,32 +818,27 @@ class CosmoQueryEngine(QueryEngineInterface):
         template = self._dataset_template
         return (self.__class__, (self._mapping, template.a, template.fa))
 
-
     def __len__(self):
         '''
         Return number of ids (keys)
         '''
         return len(self.ids)
 
-
     def train(self, dataset):
         '''
         This method does nothing
         '''
         pass
 
-
     def untrain(self):
         '''
         This method does nothing
         '''
         pass
 
-
     def query(self, **kwargs):
         raise NotImplementedError
 
-
     def query_byid(self, id):
         '''
         Returns
@@ -850,7 +850,6 @@ class CosmoQueryEngine(QueryEngineInterface):
 
         return self._mapping[id]
 
-
     @property
     def ids(self):
         '''
@@ -862,7 +861,6 @@ class CosmoQueryEngine(QueryEngineInterface):
 
         return self._ids
 
-
     @property
     def a(self):
         '''
@@ -873,7 +871,6 @@ class CosmoQueryEngine(QueryEngineInterface):
         '''
         return self._dataset_template.a
 
-
     @property
     def fa(self):
         '''
@@ -885,7 +882,6 @@ class CosmoQueryEngine(QueryEngineInterface):
         '''
         return self._dataset_template.fa
 
-
     def set_output_dataset_attributes(self, ds):
         '''
         Set attributes to output dataset (e.g. after running a searchlight)
@@ -940,7 +936,6 @@ class CosmoSearchlight(Searchlight):
     either from a .mat matlab file or through a CosmoQueryEngine
     '''
 
-
     def __init__(self, datameasure, nbrhood, add_center_fa=False,
                  results_postproc_fx=None,
                  results_backend='native',
@@ -1009,7 +1004,6 @@ class CosmoSearchlight(Searchlight):
                                                nblocks=nblocks,
                                                **kwargs)
 
-
     def _call(self, ds):
         '''
         Perform standard searchlight analysis, then update
