@@ -33,8 +33,8 @@ from mvpa2.base.types import asobjarray
 from mvpa2.base.dochelpers import enhanced_doc_string, _str, _repr_attrs
 from mvpa2.base import externals, warning
 from mvpa2.clfs.stats import auto_null_dist
-from mvpa2.base.dataset import AttrDataset, vstack
-from mvpa2.datasets import Dataset, vstack, hstack
+from mvpa2.base.dataset import AttrDataset, vstack, hstack
+from mvpa2.datasets import Dataset
 from mvpa2.mappers.fx import BinaryFxNode
 from mvpa2.generators.splitters import Splitter
 
@@ -93,11 +93,13 @@ class Measure(Learner):
     __doc__ = enhanced_doc_string('Measure', locals(),
                                   Learner)
 
-    def __repr__(self, prefixes=[]):
+    def __repr__(self, prefixes=None):
         """String representation of a `Measure`
 
         Includes only arguments which differ from default ones
         """
+        if prefixes is None:
+            prefixes = []
         return super(Measure, self).__repr__(
             prefixes=prefixes
             + _repr_attrs(self, ['null_dist']))
@@ -105,7 +107,7 @@ class Measure(Learner):
 
     def _precall(self, ds):
         # estimate the NULL distribution when functor is given
-        if not self.__null_dist is None:
+        if self.__null_dist is not None:
             if __debug__:
                 debug("STAT", "Estimating NULL distribution using %s"
                       % self.__null_dist)
@@ -208,9 +210,11 @@ class ProxyMeasure(Measure):
         self.__measure = measure
         self.skip_train = skip_train
 
-    def __repr__(self, prefixes=[]):
+    def __repr__(self, prefixes=None):
         """String representation of a `ProxyMeasure`
         """
+        if prefixes is None:
+            prefixes = []
         return super(ProxyMeasure, self).__repr__(
             prefixes=prefixes
             + _repr_attrs(self, ['measure'])
@@ -256,7 +260,7 @@ class RepeatedMeasure(Measure):
 
     def __init__(self,
                  node,
-                 generator,
+                 generator=None,
                  callback=None,
                  concat_as='samples',
                  **kwargs):
@@ -266,16 +270,17 @@ class RepeatedMeasure(Measure):
         node : Node
           Node or Measure implementing the procedure that is supposed to be run
           multiple times.
-        generator : Node
+        generator : Node, optional
           Generator to yield a dataset for each measure run. The number of
-          datasets returned by the node determines the number of runs.
-        callback : functor
+          datasets returned by the node determines the number of runs.  If no
+          generator provided, a single input dataset is passed into the node.
+        callback : functor, optional
           Optional callback to extract information from inside the main loop of
           the measure. The callback is called with the input 'data', the 'node'
           instance that is evaluated repeatedly and the 'result' of a single
           evaluation -- passed as named arguments (see labels in quotes) for
           every iteration, directly after evaluating the node.
-        concat_as : {'samples', 'features'}
+        concat_as : {'samples', 'features'}, optional
           Along which axis to concatenate result dataset from all iterations.
           By default, results are 'vstacked' as multiple samples in the output
           dataset. Setting this argument to 'features' will change this to
@@ -288,7 +293,11 @@ class RepeatedMeasure(Measure):
         self._callback = callback
         self._concat_as = concat_as
 
-    def __repr__(self, prefixes=[], exclude=[]):
+    def __repr__(self, prefixes=None, exclude=None):
+        if prefixes is None:
+            prefixes = []
+        if exclude is None:
+            exclude = []
         return super(RepeatedMeasure, self).__repr__(
             prefixes=prefixes
             + _repr_attrs(self, [x for x in ['node', 'generator', 'callback']
@@ -305,7 +314,7 @@ class RepeatedMeasure(Measure):
         space = self.get_space()
         concat_as = self._concat_as
 
-        if self.ca.is_enabled("stats") and (not node.ca.has_key("stats") or
+        if self.ca.is_enabled("stats") and (not 'stats' in node.ca or
                                             not node.ca.is_enabled("stats")):
             warning("'stats' conditional attribute was enabled, but "
                     "the assigned node '%s' either doesn't support it, "
@@ -315,7 +324,9 @@ class RepeatedMeasure(Measure):
 
         # run the node an all generated datasets
         results = []
-        for i, sds in enumerate(generator.generate(ds)):
+        for i, sds in enumerate(generator.generate(ds)
+                                if generator
+                                else [ds]):
             if __debug__:
                 debug('REPM', "%d-th iteration of %s on %s",
                       (i, self, sds))
@@ -325,7 +336,7 @@ class RepeatedMeasure(Measure):
             # run the beast
             result = node(sds)
             # callback
-            if not self._callback is None:
+            if self._callback is not None:
                 self._callback(data=sds, node=node, result=result)
             # subclass postprocessing
             result = self._repetition_postcall(sds, node, result)
@@ -338,7 +349,7 @@ class RepeatedMeasure(Measure):
             # store
             results.append(result)
 
-            if ca.is_enabled("stats") and node.ca.has_key("stats") \
+            if ca.is_enabled("stats") and 'stats' in node.ca \
                and node.ca.is_enabled("stats"):
                 if not ca.is_set('stats'):
                     # create empty stats container of matching type
@@ -355,7 +366,7 @@ class RepeatedMeasure(Measure):
         elif concat_as == 'features':
             results = hstack(results, True)
         else:
-            raise ValueError("Unkown concatenation mode '%s'" % concat_as)
+            raise ValueError("Unknown concatenation mode '%s'" % concat_as)
         # no need to store the raw results, since the Measure class will
         # automatically store them in a CA
         return results
@@ -402,7 +413,7 @@ class CrossValidation(RepeatedMeasure):
     sets of dataset partitions for leave-one-out folding). For each dataset
     instance a transfer measure is computed by splitting the dataset into
     two parts (defined by the dataset generators output space) and train a
-    custom learner on the first part and run it on the next. An arbitray error
+    custom learner on the first part and run it on the next. An arbitrary error
     function can by used to determine the learner's error when prediction the
     dataset part that has been unseen during training.
     """
@@ -412,20 +423,21 @@ class CrossValidation(RepeatedMeasure):
        across all cross-validation fold.""")
 
     # TODO move conditional attributes from CVTE into this guy
-    def __init__(self, learner, generator, errorfx=mean_mismatch_error,
+    def __init__(self, learner, generator=None, errorfx=mean_mismatch_error,
                  splitter=None, **kwargs):
         """
         Parameters
         ----------
         learner : Learner
           Any trainable node that shall be run on the dataset folds.
-        generator : Node
+        generator : Node, optional
           Generator used to resample the input dataset into multiple instances
           (i.e. partitioning it). The number of datasets yielded by this
           generator determines the number of cross-validation folds.
           IMPORTANT: The ``space`` of this generator determines the attribute
           that will be used to split all generated datasets into training and
-          testing sets.
+          testing sets. If None provided, a single original dataset will be
+          passed to the ``splitter`` as is
         errorfx : Node or callable
           Custom implementation of an error function. The callable needs to
           accept two arguments (1. predicted values, 2. target values).  If not
@@ -435,7 +447,8 @@ class CrossValidation(RepeatedMeasure):
           part. The first split will be used for training and the second for
           testing -- all other splits will be ignored. If None, a default
           splitter is auto-generated using the ``space`` setting of the
-          ``generator``. The default splitter is configured to return the
+          ``generator``.  If no ``generator`` provided, splitter uses 'partitions'
+          sample attribute. The default splitter is configured to return the
           ``1``-labeled partition of the input dataset at first, and the
           ``2``-labeled partition second. This behavior corresponds to most
           Partitioners that label the taken-out portion ``2`` and the remainder
@@ -443,7 +456,7 @@ class CrossValidation(RepeatedMeasure):
         """
         # compile the appropriate repeated measure to do cross-validation from
         # pieces
-        if not errorfx is None:
+        if errorfx is not None:
             # error node -- postproc of transfer measure
             if isinstance(errorfx, Node):
                 enode = errorfx
@@ -460,14 +473,16 @@ class CrossValidation(RepeatedMeasure):
             # because it is guaranteed to yield two splits) and is more likely
             # to fail in visible ways if the attribute does not have 0,1,2
             # values at all (i.e. a literal train/test/spareforlater attribute)
-            splitter = Splitter(generator.get_space(), attr_values=(1, 2))
+            splitter = Splitter(
+                    generator.get_space() if generator else 'partitions',
+                    attr_values=(1, 2))
         # transfer measure to wrap the learner
         # splitter used the output space of the generator to know what to split
         tm = TransferMeasure(learner, splitter, postproc=enode)
 
         space = kwargs.pop('space', 'sa.cvfolds')
         # and finally the repeated measure to perform the x-val
-        RepeatedMeasure.__init__(self, tm, generator, space=space,
+        RepeatedMeasure.__init__(self, tm, generator=generator, space=space,
                                  **kwargs)
 
         for ca in ['stats', 'training_stats']:
@@ -478,7 +493,9 @@ class CrossValidation(RepeatedMeasure):
             # also enable training stats in the learner
             learner.ca.enable('training_stats')
 
-    def __repr__(self, prefixes=[]):
+    def __repr__(self, prefixes=None):
+        if prefixes is None:
+            prefixes = []
         return super(CrossValidation, self).__repr__(
             prefixes=prefixes
             + _repr_attrs(self, ['learner', 'splitter'])
@@ -564,7 +581,9 @@ class TransferMeasure(Measure):
         self.__splitter = splitter
 
 
-    def __repr__(self, prefixes=[]):
+    def __repr__(self, prefixes=None):
+        if prefixes is None:
+            prefixes = []
         return super(TransferMeasure, self).__repr__(
             prefixes=prefixes
             + _repr_attrs(self, ['measure', 'splitter'])
@@ -635,7 +654,7 @@ class TransferMeasure(Measure):
                     estimates=measure.ca.get('estimates', None))
                 ca.stats = stats
         if ca.is_enabled('training_stats'):
-            if measure.ca.has_key("training_stats") \
+            if 'training_stats' in measure.ca \
                and measure.ca.is_enabled("training_stats"):
                 ca.training_stats = measure.ca.training_stats
             else:
@@ -693,7 +712,9 @@ class StaticMeasure(Measure):
         self.__measure = measure
         self.__bias = bias
 
-    def __repr__(self, prefixes=[]):
+    def __repr__(self, prefixes=None):
+        if prefixes is None:
+            prefixes = []
         return super(StaticMeasure, self).__repr__(
             prefixes=prefixes
             + _repr_attrs(self, ['measure', 'bias'])
@@ -710,9 +731,11 @@ class StaticMeasure(Measure):
 
 
 
-def _dont_force_slaves(slave_kwargs={}):
+def _dont_force_slaves(slave_kwargs=None):
     """Helper to reset force_train in sensitivities with slaves
     """
+    if slave_kwargs is None:
+        slave_kwargs = {}
     # We should not (or even must not in case of SplitCLF) force
     # training of slave analyzers since they would be trained
     # anyways by the Boosted analyzer's train
@@ -768,7 +791,9 @@ class Sensitivity(FeaturewiseMeasure):
         """Classifier used to computed sensitivity"""
 
 
-    def __repr__(self, prefixes=[]):
+    def __repr__(self, prefixes=None):
+        if prefixes is None:
+            prefixes = []
         return super(Sensitivity, self).__repr__(
             prefixes=prefixes
             + _repr_attrs(self, ['clf'])
@@ -866,7 +891,9 @@ class CombinedFeaturewiseMeasure(FeaturewiseMeasure):
         """List of analyzers to use"""
 
 
-    def __repr__(self, prefixes=[]):
+    def __repr__(self, prefixes=None):
+        if prefixes is None:
+            prefixes = []
         return super(CombinedFeaturewiseMeasure, self).__repr__(
             prefixes=prefixes
             + _repr_attrs(self, ['analyzers'])
