@@ -22,16 +22,29 @@ import re
 
 from mvpa2.base import externals
 
-if externals.exists("pylab", raise_=True):
-    import pylab as pl
-
 if externals.exists("matplotlib", raise_=True):
     import matplotlib.pyplot as plt
 
-
 if externals.exists("griddata", raise_=True):
     from mvpa2.support.griddata import griddata
 
+from mvpa2.support.nibabel.surf import vector_alignment_find_rotation
+
+# older versions of Numpy do not support nanmin/nanmax, so provide that here
+def _get_nan_vector_operator(func):
+    def f(xs):
+        if not len(xs.shape) == 1:
+            raise ValueError('Only vector input is supported')
+        msk = np.logical_not(np.isnan(xs))
+        return func(xs[msk])
+
+    return f
+
+
+
+nanmin_wrapper = _get_nan_vector_operator(np.min)
+nanmax_wrapper = _get_nan_vector_operator(np.max)
+
 
 
 def unstructured_xy2grid_xy_vectors(x, y, min_nsteps):
@@ -70,13 +83,23 @@ def unstructured_xy2grid_xy_vectors(x, y, min_nsteps):
 
     return xi, yi
 
-def flat_surface2xy(surface):
+
+
+def flat_surface2xy(surface, max_deformation):
     '''Returns a tuple with x and y coordinates of a flat surface
     
     Parameters
     ----------
     surface: Surface
         flat surface
+    max_deformation: float
+        maximum deformation to make a non-flat surface flat.
+        The normals of each face must have a dot product with the average
+        face normal that is not less than (1-max_deformation); otherwise
+        an exception is raised. The rationale for this option is that certain
+        surfaces may be almost flat, and those can be made flat without
+        problem; but surfaces that are not flat, such as inflated surfaces,
+        should not be flattable.
     
     Returns
     -------
@@ -92,17 +115,36 @@ def flat_surface2xy(surface):
     '''
 
     s = surf.from_any(surface)
-    v = s.vertices
-    if any(v[:, 2] != 0):
-        raise ValueError("Expected a flat surface with z=0 for all nodes")
+    face_normals = s.face_normals
 
-    x = v[:, 0]
-    y = v[:, 1]
+    msk = np.all(np.logical_not(np.isnan(face_normals)), 1)
+
+    avg_face_normal = s.nanmean_face_normal
+    deformations = abs(
+        1 - abs(np.dot(avg_face_normal[np.newaxis], face_normals[msk].T)))
+    too_deformed = np.nonzero(deformations > max_deformation)[0]
+    if len(too_deformed) > 0:
+        raise ValueError('Surface is not sufficiently flat with '
+                         'max_deformation=%.3f' % max_deformation)
+
+    # find rotation so that surface is more or less orthogonal to
+    # the unit vector (0,0,1)
+    v = s.vertices
+    z_axis = np.asarray([0, 0, 1.])
+    r = vector_alignment_find_rotation(avg_face_normal, z_axis)
+
+    # apply rotation
+    v_rotated = r.dot(v.T)
+
+    # discard z-coordinate
+    x = v_rotated[0]
+    y = v_rotated[1]
 
     return x, y
 
 
-def flat_surface2grid_mask(surface, min_nsteps):
+
+def flat_surface2grid_mask(surface, min_nsteps, max_deformation):
     '''Computes a mask and corresponding coordinates from a flat surface 
     
     Parameters
@@ -111,6 +153,16 @@ def flat_surface2grid_mask(surface, min_nsteps):
         flat surface
     min_nsteps: int
         minimum number of pixels in x and y direction
+    max_deformation: float
+        maximum deformation to make a non-flat surface flat.
+        The normals of each face must have a dot product with the average
+        face normal that is not less than (1-max_deformation); otherwise
+        an exception is raised. The rationale for this option is that
+        certain surfaces may be almost flat, and projecting the vertices
+        on a truly flat surface should be fine. On the other hand, surfaces
+        that are definitly not flat (such as full cortical surface models)
+        should cause an error to be raised when it is attempted to flatten
+        them
         
     Returns
     -------
@@ -132,10 +184,10 @@ def flat_surface2grid_mask(surface, min_nsteps):
     '''
 
     surface = surf.from_any(surface)
-    x, y = flat_surface2xy(surface)
+    x, y = flat_surface2xy(surface, max_deformation)
     xmin = np.min(x)
 
-    xi, yi = unstructured_xy2grid_xy_vectors(x, y , min_nsteps)
+    xi, yi = unstructured_xy2grid_xy_vectors(x, y, min_nsteps)
     delta = xi[1] - xi[0]
     vi2xi = (x - xmin) / delta
 
@@ -190,17 +242,18 @@ def flat_surface2grid_mask(surface, min_nsteps):
 
     return x, y, msk, xi, yi
 
+
+
 def _scale(xs, target_min=0., target_max=1., source_min=None, source_max=None):
     '''Scales from [smin,smax] to [tmin,tmax]'''
-    mn = np.nanmin(xs, axis= -1)[np.newaxis].T if source_min is None\
-                                                             else source_min
-    mx = np.nanmax(xs, axis= -1)[np.newaxis].T if source_max is None\
-                                                             else source_max
+    mn = nanmin_wrapper(xs.ravel()) if source_min is None else source_min
+    mx = nanmax_wrapper(xs.ravel()) if source_max is None else source_max
 
     scaled = (xs - mn) / (mx - mn)
     return scaled * (target_max - target_min) + target_min
 
 
+
 def flat_surface_curvature2rgba(curvature):
     '''Computes an RGBA colormap in black and white, based on curvature'''
     curvature = curvature_from_any(curvature)
@@ -212,6 +265,8 @@ def flat_surface_curvature2rgba(curvature):
 
     return cmap(c)
 
+
+
 def _range2min_max(range_, xs):
     '''Converts a range description to a minimum and maximum value
 
@@ -254,8 +309,8 @@ def _range2min_max(range_, xs):
 
             percentage = p == '%'
             if percentage:
-                xmn = np.nanmin(xs)
-                xmx = np.nanmax(xs)
+                xmn = nanmin_wrapper(xs.ravel())
+                xmx = nanmax_wrapper(xs.ravel())
 
                 mx = 100 - mn if mx != 0 and not mx else float(mx)
 
@@ -272,8 +327,8 @@ def _range2min_max(range_, xs):
 
 
 
-
-def flat_surface_data2rgba(data, range_='2_98%', threshold=None, color_map=None):
+def flat_surface_data2rgba(data, range_='2_98%', threshold=None,
+                           color_map=None):
     '''Computes an RGBA colormap for surface data'''
 
     if isinstance(data, Dataset):
@@ -291,16 +346,19 @@ def flat_surface_data2rgba(data, range_='2_98%', threshold=None, color_map=None)
 
     return rgba
 
+
+
 def curvature_from_any(c):
     '''Reads curvature'''
     if isinstance(c, basestring):
         from mvpa2.support.nibabel import afni_suma_1d
+
         c = afni_suma_1d.from_any(c)
 
         # typical SUMA use case: first column has node indices,
         # second column 
         if len(c.shape) > 1 and c.shape[1] == 2 and \
-                set(c[:, 0]) == set(range(1 + int(max(c[:, 0])))):
+                        set(c[:, 0]) == set(range(1 + int(max(c[:, 0])))):
             cc = c
             n = cc.shape[0]
             c = np.zeros((n,))
@@ -309,10 +367,31 @@ def curvature_from_any(c):
 
     return np.asarray(c)
 
+
+
 class FlatSurfacePlotter(object):
-    '''Plots data on a flat surface'''
+    '''Plots data on a flat surface
+
+    Example
+    =======
+    flat_surf_fn = 'flat_anat_surface.surf.gii'
+    ds = h5load('surface_data.h5py')
+
+    # plot data on surface
+    fsp = FlatSurfacePlotter(flat_surf_fn)
+    img = fsp(ds.samples[0])
+
+    # plot data with threshold and curvature
+    conv_fn='ico16_lh.conv.1D.dset' # from AFNI SUMA's SurfaceMetrics -conv
+    fsp_thr=FSP(flat_surf_fn,
+                curvature = conv_fn,
+                threshold=(.5, .8))
+    img_thr=fsp_thr(sl_dset.samples[0])
+    '''
+
     def __init__(self, surface, curvature=None, min_nsteps=500,
-                        range_='2_98%', threshold=None, color_map=None):
+                 range_='2_98%', threshold=None, color_map=None,
+                 max_deformation=.5):
         '''
         Parameters
         ----------
@@ -335,6 +414,16 @@ class FlatSurfacePlotter(object):
             Indicates which values will be shown. Syntax as in range_
         color_map: str
             colormap to use
+        max_deformation: float
+            maximum deformation to make a non-flat surface flat.
+            The normals of each face must have a dot product with the average
+            face normal that is not less than (1-max_deformation); otherwise
+            an exception is raised. The rationale for this option is that
+            certain surfaces may be almost flat, and projecting the vertices
+            on a truly flat surface should be fine. On the other hand, surfaces
+            that are definitly not flat (such as full cortical surface models)
+            should cause an error to be raised when it is attempted to flatten
+            them
         '''
 
         self._surface = surf.from_any(surface)
@@ -343,14 +432,17 @@ class FlatSurfacePlotter(object):
             self._curvature = None
         else:
             self._curvature = curvature_from_any(curvature)
-            if self._surface.nvertices != self._curvature.size:
-                raise ValueError("Surface has %d vertices, but curvature %d" %
-                                  (self._surface.nvertices, self._curvature.size))
+            if self._surface.nvertices != len(self._curvature):
+                raise ValueError("Surface has %d vertices, but curvature "
+                                 "has %d values" %
+                                 (self._surface.nvertices,
+                                  self._curvature.size))
 
         self._min_nsteps = min_nsteps
         self._range_ = range_
         self._threshold = threshold
         self._color_map = color_map
+        self._max_deformation = max_deformation
 
         self._grid_def = None
         self._underlay = None
@@ -359,7 +451,6 @@ class FlatSurfacePlotter(object):
         '''Sets the underlay'''
         self._underlay = u.copy()
 
-
     def _set_underlay_from_curvature(self):
         if self._curvature is None:
             raise ValueError("Curvature is not set")
@@ -369,7 +460,7 @@ class FlatSurfacePlotter(object):
 
         x, y, msk, xi, yi = self._grid_def
 
-        ulay = griddata(x, y, self._curvature, xi, yi)
+        ulay = griddata(x, y, self._curvature, xi, yi, interp='linear')
         ulay[-msk] = np.nan
 
         rgba = flat_surface_curvature2rgba(ulay)
@@ -377,13 +468,13 @@ class FlatSurfacePlotter(object):
 
     def _pre_setup(self):
         if self._grid_def is None:
-            self._grid_def = flat_surface2grid_mask(self._surface, \
-                                                    self._min_nsteps)
+            self._grid_def = flat_surface2grid_mask(self._surface,
+                                                    self._min_nsteps,
+                                                    self._max_deformation)
 
         if self._underlay is None and self._curvature is not None:
             self._set_underlay_from_curvature()
 
-
     def __call__(self, data):
         '''
         Parameters
@@ -398,21 +489,28 @@ class FlatSurfacePlotter(object):
             Bitmap with RGBA values that can be plotted.
         '''
         self._pre_setup()
-        x, y, msk, xi, yi = self._grid_def
-        olay = griddata(x, y, data, xi, yi)
-        olay[-msk] = np.nan
 
-        o_rgba = flat_surface_data2rgba(olay, self._range_ , self._threshold,
-                                                self._color_map)
-        o_rgba[-msk] = np.nan # apply the mask again, to be sure
+        expected_shape = (self._surface.nvertices,)
+        if data.shape != expected_shape:
+            raise ValueError('data shape was expected to be %s based on '
+                             'the number of nodes of the surface, '
+                             'found %s' % (
+                                 expected_shape, data.shape))
+
+        x, y, msk, xi, yi = self._grid_def
+        olay = griddata(x, y, data, xi, yi, interp='linear')
+        nan_msk = np.logical_not(msk)
+        olay[nan_msk] = np.nan
+        o_rgba = flat_surface_data2rgba(olay, self._range_, self._threshold,
+                                        self._color_map)
+        o_rgba[nan_msk] = np.nan  # apply the mask again, to be sure
 
         if self._underlay is not None:
             o_msk = -np.isnan(np.sum(o_rgba, 2))
 
             u_rgba = self._underlay
-            u_msk = np.logical_and(-o_msk, msk)
+            u_msk = np.logical_and(np.logical_not(o_msk), msk)
 
             o_rgba[u_msk] = u_rgba[u_msk]
 
         return o_rgba
-
