@@ -126,6 +126,7 @@ def collect_unit_tests(verbosity=1):
         'test_svdmapper',
         'test_procrust',
         'test_hyperalignment',
+        'test_searchlight_hyperalignment',
         'test_transformers',
         'test_searchlight',
         'test_rfe',
@@ -138,7 +139,6 @@ def collect_unit_tests(verbosity=1):
 
     __optional_tests = [ ('scipy', 'ridge'),
                          ('scipy', 'gpr'),
-                         (['cPickle', 'gzip'], 'hamster'),
                        ]
 
     # and now for the optional tests
@@ -194,6 +194,7 @@ def collect_nose_tests(verbosity=1):
 
         # Classifiers
         'test_multiclf',
+        'test_smlr',
 
         # Misc supporting
         'test_neighborhood',
@@ -239,6 +240,7 @@ def collect_nose_tests(verbosity=1):
         'test_datameasure',
         'test_dcov',
         'test_corrstability',
+        'test_fxmeasure',
         'test_rsa',
 
         # Misc
