@@ -63,10 +63,11 @@ class KNNTests(unittest.TestCase):
         self.assertTrue(not (clf.ca.distances.fa['chunks'] is train.sa['chunks']))
         self.assertTrue(not (clf.ca.distances.fa.chunks is train.sa.chunks))
 
-def suite():
+def suite():  # pragma: no cover
     return unittest.makeSuite(KNNTests)
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma: no cover
     import runner
+    runner.run()
 
